@@ -7,8 +7,9 @@ def main():
                         help="path of json config file")
     parser.add_argument("archive_path",
                         help="path of archive from arche")
-    parser.add_argument("--ws",
+    parser.add_argument("-ws", "--workspace",
                         help="where to build workspace")
-    parser.add_argument("-v", "--verbose", help="increase output verbosity",
-                        action="store_true")
+    parser.add_argument("-v", "--verbosity",
+                        help="increase output verbosity",
+                        type=int, choices=[0, 1, 2], default=0)
     fe = FastEval(parser.parse_args())
